Crate auto_registry

Crate auto_registry 

Attribute Macros

auto_registry
The proc macro used on a struct to add it to the registry
generate_registry
The proc macro that generates the function to build the registry