Crate auto_registry
auto_
registry
0.0.2
All Items
Crate Items
Attribute Macros
Crate
auto_
registry
Attribute Macros

auto_
registry
The proc macro used on a struct to add it to the registry
generate_
registry
The proc macro that generates the function to build the registry